#!/bin/sh
#
# Build the Booke. First assemble the book LaTeX, then build it
# into a PDF.
#

if [ $# != 1 ]; then
    echo "Usage: make.sh <book dir name>"
    exit 1
fi

dir=`pwd`

booke=$dir/$1
builddir=$dir/build
output=dottes.tex

mkdir -p $builddir

cp dottes.tex.header $builddir/$output

# Now, for each tune, add
#
# \addcontentsline{toc}{subsection}{<Tune title>}
# \begin{abc}[name=<filename>]
# ... ABC ...
# \end{abc}

find $booke -name "*.abc" | sort |
    while read filename
    do
        title=`grep "^T:" $filename | head -1 | sed -e "s/^T: *//"`
        name=`basename $filename .abc`
        echo "\\\\addcontentsline{toc}{subsection}{$title}" >> $builddir/$output
        echo "\\\\begin{abc}[options=-j0 +c -n,name=$name]" >> $builddir/$output
        cat $filename >> $builddir/$output
        echo "\\\\end{abc}" >> $builddir/$output
    done

cat dottes.tex.footer >> $builddir/$output

cd $builddir
pdflatex -shell-escape $output
pdflatex -shell-escape $output

cd $dir
pdflatex dottesona4.tex
